@@ -1,3 +1,4 @@
+from pydoc import plain
 from time import sleep
 from typing import Any, List, Tuple
 import logging
@@ -7,14 +8,14 @@ from requests import Timeout
 from colorama import Fore, Style
 from pydantic import ValidationError
 
-from schema import Piece, Move, Player, InvalidMovesMessage, BotResponse, PlayerMove
-from custom_exceptions import InvalidMovesException, TimeoutException, MovesExceededException
-from constants import MAX_MOVES_ALLOWED
-from logger_utils import get_logger, game_visualizer
+from .schema import Piece, Move, Player, InvalidMovesMessage, BotResponse, PlayerMove, Position
+from .custom_exceptions import InvalidMovesException, TimeoutException, MovesExceededException
+from .constants import MAX_MOVES_ALLOWED
+from .logger_utils import get_logger, game_visualizer
 
 
 class Simulator:
-    def __init__(self, move_timeout: int = 4, verbose: bool = True, logging_level: int = logging.WARNING) -> None:
+    def __init__(self, move_timeout: int = 4, visualize: bool = True, logging_level: int = logging.WARNING) -> None:
         pieces = ['B', 'b', '_', 'r', 'R']
         self.board = [[pieces[i] for _ in range(5)] for i in range(5)]
         self.RED_PIECES = [Piece.RED_BOMBER, Piece.RED_STINGER]
@@ -22,7 +23,8 @@ class Simulator:
         self.move_timeout = move_timeout
         self.logger = get_logger(__name__, level=logging_level)
         self.visualizer = game_visualizer(level=logging_level)
-        self.verbose = verbose
+        if visualize:
+            self.visualizer.setLevel(level=logging.INFO)
 
     def print_board(self):
         """
@@ -182,7 +184,7 @@ class Simulator:
             return True, Player.BLUE
         return False, None
 
-    def run(self, bot_urls: List[str], bot_data: List[Any], player_moves: List[PlayerMove]):
+    def simulate(self, bot_urls: List[str], bot_data: List[Any], player_moves: List[PlayerMove]):
         player = Player.BLUE
         self.logger.debug("Starting game simulation")
         self.print_board()
@@ -240,3 +242,37 @@ class Simulator:
             except InvalidMovesException as ex:
                 self.logger.error(f"Invalid response received from player: {player}. Message: {ex.message}")
                 raise InvalidMovesException(reason=ex.reason, player=player)  # append player info to exception
+
+    def play(self):
+        self.print_board()
+        self.visualizer.info(Fore.BLACK + Style.BRIGHT +
+                             "Enter the inputs turn by turn in the following format: <src row> <src col> <dst row> <dst col>")
+        self.visualizer.info("Spaces matter!")
+        self.visualizer.info(Fore.RESET + Style.RESET_ALL)
+        player = Player.BLUE
+        while not self.check_if_game_over()[0]:
+            prompt_color = Fore.BLUE if player == Player.BLUE else Fore.RED
+            input_string = input(prompt_color + f"Player {player}:\n" + Fore.RESET)
+            try:
+                positions = [int(pos) for pos in input_string.split(" ")]
+                move = Move(src=Position(row=positions[0], col=positions[1]), dst=Position(row=positions[2], col=positions[3]))
+                self.validate_move(move=move, player=player)
+                self.make_move(move=move, player=player)
+                self.print_board()
+                if player == Player.BLUE:
+                    player = player.RED
+                else:
+                    player = Player.BLUE
+            except InvalidMovesException as ex:
+                self.visualizer.error(Fore.RED + Style.BRIGHT + f"Entered move was invalid. Reason: {str(ex)}")
+                self.visualizer.info(Fore.BLACK + Style.BRIGHT + f"Play again as player {player}")
+                self.print_board()
+                self.visualizer.info(Fore.RESET + Style.RESET_ALL)
+            except Exception as ex:
+                self.visualizer.error(Fore.RED + Style.BRIGHT + f"Entered move format was incorrect. Play again as player {player}")
+                self.visualizer.info("Enter the inputs in the following format: <src row> <src col> <dst row> <dst col>")
+                self.visualizer.info("Spaces matter!")
+                self.print_board()
+        _, winner = self.check_if_game_over()
+        prompt_color = Fore.BLUE if winner == Player.BLUE else Fore.RED
+        self.visualizer.info(prompt_color + f"Player {winner} wins!" + Fore.RESET)
